@@ -21,10 +21,8 @@ class Utility:
     def __init__(self):
         self.encryption_key = os.getenv('FERNET_KEY')
 
-
     def render_prompt_from_template(self,
                                     template_pathname: str,
-                                    query: str = None,
                                     client_data: dict = {},
                                     **kwargs) -> str:
 
@@ -37,8 +35,6 @@ class Utility:
             env = Environment(loader=FileSystemLoader(template_dir))
             template = env.get_template(template_file)
 
-            kwargs["query"] = query
-
             # add all the keys in client_data to kwargs
             kwargs.update(client_data)
 
@@ -53,7 +49,6 @@ class Utility:
     def render_prompt_from_string(self,
                                   template_string: str,
                                   searchpath: str | list[str] = None,
-                                  query: str = None,
                                   client_data: dict = {},
                                   **kwargs) -> str:
         """
@@ -76,7 +71,6 @@ class Utility:
             env = Environment(loader=loader)
             template = env.from_string(template_string)
 
-            kwargs["query"] = query
             kwargs.update(client_data)
 
             prompt = template.render(**kwargs)
@@ -87,6 +81,23 @@ class Utility:
                                f'No se pudo renderizar el template desde el string, error: {str(e)}') from e
 
 
+    def get_company_template(self, company_short_name: str, template_name: str) -> str:
+        # 1. get the path to the company specific template
+        template_path = os.path.join(os.getcwd(), f'companies/{company_short_name}/templates/{template_name}')
+        if not os.path.exists(template_path):
+            return None
+
+        # 2. read the file
+        try:
+            with open(template_path, 'r') as f:
+                template_string = f.read()
+
+            return template_string
+        except Exception as e:
+            logging.exception(e)
+            return None
+
+
     def serialize(self, obj):
         if isinstance(obj, datetime) or isinstance(obj, date):
             return obj.isoformat()
