@@ -229,14 +229,12 @@ const callToolkit = async function(apiPath, data, method, timeoutMs = 500000) {
 
         }
         const response = await fetch(url, fetchOptions);
-
         clearTimeout(timeoutId);
-
         if (!response.ok) {
             try {
                 // Intentamos leer el error como JSON, que es el formato esperado de nuestra API.
                 const errorData = await response.json();
-                const errorMessage = errorData.error_message || 'Error desconocido del servidor.';
+                const errorMessage = errorData.error_message || t_js('unknown_server_error'); // <-- Translation
                 const errorIcon = '<i class="bi bi-exclamation-triangle"></i>';
                 const endpointError = $('<div>').addClass('error-section').html(errorIcon + `<p>${errorMessage}</p>`);
                 displayBotMessage(endpointError);
@@ -244,9 +242,7 @@ const callToolkit = async function(apiPath, data, method, timeoutMs = 500000) {
                 // Si response.json() falla, es porque el cuerpo no era JSON (ej. un 502 con HTML).
                 // Mostramos un error genérico y más claro para el usuario.
                 const errorMessage = `Error de comunicación con el servidor (${response.status}). Por favor, intente de nuevo más tarde.`;
-                const errorIcon = '<i class="bi bi-exclamation-triangle"></i>';
-                const infrastructureError = $('<div>').addClass('error-section').html(errorIcon + `<p>${errorMessage}</p>`);
-                displayBotMessage(infrastructureError);
+                toastr.error(errorMessage);
             }
             return null;
         }
@@ -256,18 +252,7 @@ const callToolkit = async function(apiPath, data, method, timeoutMs = 500000) {
         if (error.name === 'AbortError') {
             throw error; // Re-throw to be handled by handleChatMessage
         } else {
-            // Log detallado en consola
-                console.error('Error de red en callToolkit:', {
-                    url,
-                    method,
-                    error,
-                    message: error?.message,
-                    stack: error?.stack,
-                });
-            const friendlyMessage = "Ocurrió un error de red. Por favor, inténtalo de nuevo en unos momentos.";
-            const errorIcon = '<i class="bi bi-exclamation-triangle"></i>';
-            const commError = $('<div>').addClass('error-section').html(errorIcon + `<p>${friendlyMessage}</p>`);
-            displayBotMessage(commError);
+            toastr.error(t_js('network_error') );
         }
         return null;
     }
@@ -327,12 +312,13 @@ const abortCurrentRequest = function () {
 const showSpinner = function () {
     if ($('#spinner').length) return;
     const accessibilityClass = (typeof bootstrap !== 'undefined') ? 'visually-hidden' : 'sr-only';
+    const spinnerText = t_js('loading');
     const spinner = $(`
         <div id="spinner" style="display: flex; align-items: center; justify-content: start; margin: 10px 0; padding: 10px;">
             <div class="spinner-border" role="status" style="width: 1.5rem; height: 1.5rem; margin-right: 15px;">
                 <span class="${accessibilityClass}">Loading...</span>
             </div>
-            <span style="font-weight: bold; font-size: 15px;">Cargando...</span>
+            <span style="font-weight: bold; font-size: 15px;">${spinnerText}</span>
         </div>
     `);
     $('#chat-container').append(spinner).scrollTop($('#chat-container')[0].scrollHeight);
