@@ -7,6 +7,7 @@ from flask.views import MethodView
 from flask import render_template, request, url_for, session, redirect, flash
 from iatoolkit.services.profile_service import ProfileService
 from iatoolkit.services.branding_service import BrandingService
+from iatoolkit.services.i18n_service import I18nService
 from itsdangerous import URLSafeTimedSerializer, SignatureExpired
 from flask_bcrypt import Bcrypt
 from injector import inject
@@ -17,49 +18,60 @@ class ChangePasswordView(MethodView):
     @inject
     def __init__(self,
                  profile_service: ProfileService,
-                 branding_service: BrandingService):
+                 branding_service: BrandingService,
+                 i18n_service: I18nService):
         self.profile_service = profile_service
-        self.branding_service = branding_service # 3. Guardar la instancia
+        self.branding_service = branding_service
+        self.i18n_service = i18n_service
 
         self.serializer = URLSafeTimedSerializer(os.getenv("PASS_RESET_KEY"))
         self.bcrypt = Bcrypt()
 
     def get(self, company_short_name: str, token: str):
-        # get company info
-        company = self.profile_service.get_company_by_short_name(company_short_name)
-        if not company:
-            return render_template('error.html', message=f"Empresa no encontrada: {company_short_name}"), 404
-
-        branding_data = self.branding_service.get_company_branding(company)
-
         try:
-            # Decodificar el token
-            email = self.serializer.loads(token, salt='password-reset', max_age=3600)
-        except SignatureExpired as e:
-            flash("El enlace de cambio de contraseña ha expirado. Por favor, solicita uno nuevo.", 'error')
-            return render_template('forgot_password.html',
-                                branding=branding_data)
+            company = self.profile_service.get_company_by_short_name(company_short_name)
+            if not company:
+                return render_template('error.html',
+                                       message=self.i18n_service.t('errors.templates.company_not_found')), 404
 
-        return render_template('change_password.html',
-                               company_short_name=company_short_name,
-                               company=company,
-                               branding=branding_data,
-                               token=token, email=email)
+            branding_data = self.branding_service.get_company_branding(company)
+
+            try:
+                # Decodificar el token
+                email = self.serializer.loads(token, salt='password-reset', max_age=3600)
+            except SignatureExpired as e:
+                flash(self.i18n_service.t('errors.change_password.token_expired'), 'error')
+                return render_template('forgot_password.html',
+                                    branding=branding_data)
+
+            return render_template('change_password.html',
+                                   company_short_name=company_short_name,
+                                   company=company,
+                                   branding=branding_data,
+                                   token=token,
+                                   email=email)
+        except Exception as e:
+            message = self.i18n_service.t('errors.templates.processing_error', error=str(e))
+            return render_template(
+                "error.html",
+                company_short_name=company_short_name,
+                branding=branding_data,
+                message=message
+            ), 500
 
     def post(self, company_short_name: str, token: str):
         # get company info
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
             return render_template('error.html',
-            company_short_name=company_short_name,
-            message=f"Empresa no encontrada: {company_short_name}"), 404
+                                   message=self.i18n_service.t('errors.templates.company_not_found')), 404
 
         branding_data = self.branding_service.get_company_branding(company)
         try:
             # Decodificar el token
             email = self.serializer.loads(token, salt='password-reset', max_age=3600)
         except SignatureExpired:
-            flash("El enlace de cambio de contraseña ha expirado. Por favor, solicita uno nuevo.", 'error')
+            flash(self.i18n_service.t('errors.change_password.token_expired'), 'error')
 
             return render_template('forgot_password.html',
                                    company_short_name=company_short_name,
@@ -92,12 +104,14 @@ class ChangePasswordView(MethodView):
                                "new_password": new_password,
                                "confirm_password": confirm_password}), 400
 
-            # Éxito: Guardar mensaje en sesión y redirigir
-            flash("Tu contraseña ha sido restablecida exitosamente. Ahora puedes iniciar sesión.", 'success')
+            flash(self.i18n_service.t('flash_messages.password_changed_success'), 'success')
             return redirect(url_for('home', company_short_name=company_short_name))
 
         except Exception as e:
-            return render_template("error.html",
-                                   company_short_name=company_short_name,
-                                   branding=branding_data,
-                                   message=f"Ha ocurrido un error inesperado: {str(e)}"), 500
+            message = self.i18n_service.t('errors.templates.processing_error', error=str(e))
+            return render_template(
+                "error.html",
+                company_short_name=company_short_name,
+                branding=branding_data,
+                message=message
+            ), 500
\ No newline at end of file
