@@ -3,7 +3,8 @@ from injector import inject
 from iatoolkit.services.query_service import QueryService
 from iatoolkit.services.profile_service import ProfileService
 from iatoolkit.services.auth_service import AuthService
-from flask import jsonify, request
+from iatoolkit.services.i18n_service import I18nService
+from flask import jsonify
 import logging
 
 
@@ -17,10 +18,12 @@ class InitContextApiView(MethodView):
     def __init__(self,
                  auth_service: AuthService,
                  query_service: QueryService,
-                 profile_service: ProfileService):
+                 profile_service: ProfileService,
+                 i18n_service: I18nService):
         self.auth_service = auth_service
         self.query_service = query_service
         self.profile_service = profile_service
+        self.i18n_service = i18n_service
 
     def post(self, company_short_name: str):
         """
@@ -28,14 +31,14 @@ class InitContextApiView(MethodView):
         an active web session or by the external_user_id in the JSON payload
         for API calls.
         """
-        # 1. Authenticate the request. This handles both session and API Key.
-        auth_result = self.auth_service.verify()
-        if not auth_result.get("success"):
-            return jsonify(auth_result), auth_result.get("status_code")
-
-        user_identifier = auth_result.get('user_identifier')
-
         try:
+            # 1. Authenticate the request. This handles both session and API Key.
+            auth_result = self.auth_service.verify()
+            if not auth_result.get("success"):
+                return jsonify(auth_result), auth_result.get("status_code")
+
+            user_identifier = auth_result.get('user_identifier')
+
             # 2. Execute the forced rebuild sequence using the unified identifier.
             self.query_service.session_context.clear_all_context(company_short_name, user_identifier)
             logging.info(f"Context for {company_short_name}/{user_identifier} has been cleared.")
@@ -52,11 +55,13 @@ class InitContextApiView(MethodView):
             )
 
             # 3. Respond with JSON, as this is an API endpoint.
-            return jsonify({'status': 'OK', 'message': 'El contexto se ha recargado con éxito.'}), 200
+            success_message = self.i18n_service.t('api_responses.context_reloaded_success')
+            return jsonify({'status': 'OK', 'message': success_message}), 200
 
         except Exception as e:
-            logging.exception(f"Error durante la recarga de contexto {user_identifier}: {e}")
-            return jsonify({"error_message": str(e)}), 500
+            logging.exception(f"errors while reloading context: {e}")
+            error_message = self.i18n_service.t('errors.general.unexpected_error', error=str(e))
+            return jsonify({"error_message": error_message}), 500
 
     def options(self, company_short_name):
         """
