@@ -13,6 +13,7 @@ from iatoolkit.services.query_service import QueryService
 from iatoolkit.services.prompt_manager_service import PromptService
 from iatoolkit.services.branding_service import BrandingService
 from iatoolkit.services.onboarding_service import OnboardingService
+from iatoolkit.services.i18n_service import I18nService
 from iatoolkit.views.base_login_view import BaseLoginView
 import logging
 
@@ -26,8 +27,7 @@ class LoginView(BaseLoginView):
         company = self.profile_service.get_company_by_short_name(company_short_name)
         if not company:
             return render_template('error.html',
-                        company_short_name=company_short_name,
-                        message="Empresa no encontrada"), 404
+                                   message=self.i18n_service.t('errors.templates.company_not_found')), 404
 
         branding_data = self.branding_service.get_company_branding(company)
         email = request.form.get('email')
@@ -63,10 +63,13 @@ class LoginView(BaseLoginView):
         try:
             return self._handle_login_path(company, user_identifier, target_url)
         except Exception as e:
-            return render_template("error.html",
-            company_short_name=company_short_name,
-            branding=branding_data,
-            message=f"Error processing login path: {str(e)}"), 500
+            message = self.i18n_service.t('errors.templates.processing_error', error=str(e))
+            return render_template(
+                "error.html",
+                company_short_name=company_short_name,
+                branding=branding_data,
+                message=message
+            ), 500
 
 
 class FinalizeContextView(MethodView):
@@ -82,6 +85,7 @@ class FinalizeContextView(MethodView):
                  branding_service: BrandingService,
                  onboarding_service: OnboardingService,
                  jwt_service: JWTService,
+                 i18n_service: I18nService
                  ):
         self.profile_service = profile_service
         self.jwt_service = jwt_service
@@ -89,33 +93,34 @@ class FinalizeContextView(MethodView):
         self.prompt_service = prompt_service
         self.branding_service = branding_service
         self.onboarding_service = onboarding_service
+        self.i18n_service = i18n_service
 
     def get(self, company_short_name: str, token: str = None):
-        session_info = self.profile_service.get_current_session_info()
-        if session_info:
-            # session exists, internal user
-            user_identifier = session_info.get('user_identifier')
-            token = ''
-        elif token:
-            # user identified by api-key
-            payload = self.jwt_service.validate_chat_jwt(token)
-            if not payload:
-                logging.warning("Fallo crítico: No se pudo leer el auth token.")
+        try:
+            session_info = self.profile_service.get_current_session_info()
+            if session_info:
+                # session exists, internal user
+                user_identifier = session_info.get('user_identifier')
+                token = ''
+            elif token:
+                # user identified by api-key
+                payload = self.jwt_service.validate_chat_jwt(token)
+                if not payload:
+                    logging.warning("Fallo crítico: No se pudo leer el auth token.")
+                    return redirect(url_for('home', company_short_name=company_short_name))
+
+                user_identifier = payload.get('user_identifier')
+            else:
+                logging.warning("Fallo crítico: missing session information or auth token")
                 return redirect(url_for('home', company_short_name=company_short_name))
 
-            user_identifier = payload.get('user_identifier')
-        else:
-            logging.warning("Fallo crítico: missing session information or auth token")
-            return redirect(url_for('home', company_short_name=company_short_name))
+            company = self.profile_service.get_company_by_short_name(company_short_name)
+            if not company:
+                return render_template('error.html',
+                            company_short_name=company_short_name,
+                            message="Empresa no encontrada"), 404
+            branding_data = self.branding_service.get_company_branding(company)
 
-        company = self.profile_service.get_company_by_short_name(company_short_name)
-        if not company:
-            return render_template('error.html',
-                        company_short_name=company_short_name,
-                        message="Empresa no encontrada"), 404
-        branding_data = self.branding_service.get_company_branding(company)
-
-        try:
             # 2. Finalize the context rebuild (the heavy task).
             self.query_service.finalize_context_rebuild(
                 company_short_name=company_short_name,
@@ -126,6 +131,9 @@ class FinalizeContextView(MethodView):
             prompts = self.prompt_service.get_user_prompts(company_short_name)
             onboarding_cards = self.onboarding_service.get_onboarding_cards(company)
 
+            # Get the entire 'js_messages' block in the correct language.
+            js_translations = self.i18n_service.get_translation_block('js_messages')
+
             return render_template(
                 "chat.html",
                 company_short_name=company_short_name,
@@ -133,6 +141,7 @@ class FinalizeContextView(MethodView):
                 branding=branding_data,
                 prompts=prompts,
                 onboarding_cards=onboarding_cards,
+                js_translations=js_translations,
                 redeem_token=token
             )
 
